@@ -2,12 +2,12 @@
 
 __author__ = """Kyle Kelley"""
 __email__ = 'rgbkrk@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.7'
 
 
 # Export Markdown from display
 
 from .display import Markdown
-from .messaging import human, ai, system
+from .messaging import ai, assistant, human, narrate, system, user
 
-__all__ = ["Markdown", "human", "ai", "system"]
+__all__ = ["Markdown", "human", "ai", "narrate", "system", "user", "assistant"]
